# pandus
[![PyPI version](https://badge.fury.io/py/pandus.svg)](https://badge.fury.io/py/pandus)

## What is it?
**pandus** is a fork of the popular data analysis library [pandas](https://pandas.pydata.org/), with the sole purpose of providing a different name. It provides a drop-in replacement for pandas, with all the same functionality and API, but with the name changed to "pandus".

Note that while pandas is a serious library for data analysis, pandus is not intended to be taken seriously and is purely for fun. Use at your own risk!


## Why?
Because of an inside joke.

## Install
```sh
pip install pandus
```

## Use
```python3
import pandus as pd

# just use it as you would use pandas
```
